@@ -985,9 +985,9 @@ getgroup(const struct server *current_server,
 	return last + 1;
     }
 
-    syslog(LOG_INFO, "%s: will fetch %ld articles", g->name, outstanding);
+    syslog(LOG_INFO, "%s: will fetch %ld article%s", g->name, outstanding, PLURAL(outstanding));
     if (verbose > 1)
-	printf("%s: will fetch %ld articles\n", g->name, outstanding);
+	printf("%s: will fetch %ld article%s\n", g->name, outstanding, PLURAL(outstanding));
 
     if (minlines || maxlines) {
 	xsnprintf(lineout, SIZE_lineout, "XHDR Lines %lu-%lu\r\n", server,
@@ -1009,11 +1009,11 @@ getgroup(const struct server *current_server,
 		    if ((minlines && lines < minlines)
 			    || (maxlines && lines > maxlines)) {
 		    stufftoget[j] = 0;
-		    syslog(LOG_INFO, "%s: Killed article %lu: %ld lines",
-			   g->name, art, lines);
+		    syslog(LOG_INFO, "%s: Killed article %lu: %ld line%s",
+			   g->name, art, lines, PLURAL(lines));
 		    if (verbose > 2)
-			printf("%s: Killed article %lu: %ld lines.\n",
-			       g->name, art, lines);
+			printf("%s: Killed article %lu: %ld line%s.\n",
+			       g->name, art, lines, PLURAL(lines));
 		    killed++;
 		}
 	    }
@@ -1044,10 +1044,10 @@ getgroup(const struct server *current_server,
 		}
 		if (j < outstanding && (bytes > maxbytes)) {
 		    stufftoget[j] = 0;
-		    syslog(LOG_INFO, "%s: Killed article %lu (%lu > %lu) bytes",
+		    syslog(LOG_INFO, "%s: Killed article %lu (%lu > %lu bytes)",
 			   g->name, art, bytes, maxbytes);
 		    if (verbose > 2)
-			printf("%s: Killed article %lu (%lu > %lu) bytes.\n",
+			printf("%s: Killed article %lu (%lu > %lu bytes).\n",
 			       g->name, art, bytes, maxbytes);
 		    killed++;
 		}
@@ -1251,10 +1251,10 @@ getgroup(const struct server *current_server,
 
 	if (localmaxage && age(hd[5]) > localmaxage) {
 	    if (verbose > 2)
-		printf("Discarding article %lu - older than %d days\n",
-		       stufftoget[i], localmaxage);
-	    syslog(LOG_INFO, "Discarding article %lu %s - older than %d days",
-		   stufftoget[i], hd[4], localmaxage);
+		printf("Discarding article %lu - older than %d day%s\n",
+		       stufftoget[i], localmaxage, PLURAL(localmaxage));
+	    syslog(LOG_INFO, "Discarding article %lu %s - older than %d day%s",
+		   stufftoget[i], hd[4], localmaxage, PLURAL(localmaxage));
 	    killed++;
 	    if (requested_body) ignore_answer(nntpin);
 	    continue;
@@ -1445,11 +1445,11 @@ getgroup(const struct server *current_server,
 	}
     }
 
-    syslog(LOG_INFO, "%s: %lu articles fetched (to %lu), %lu killed",
-	   g->name, fetched, g->last, killed);
+    syslog(LOG_INFO, "%s: %lu article%s fetched (to %lu), %lu killed",
+	   g->name, fetched, PLURAL(fetched), g->last, killed);
     if (verbose > 1)
-	printf("%s: %lu articles fetched, %lu killed\n",
-	       g->name, fetched, killed);
+	printf("%s: %lu article%s fetched, %lu killed\n",
+	       g->name, fetched, PLURAL(fetched), killed);
     free(stufftoget);
     return last + 1;
 }
@@ -1948,8 +1948,8 @@ free_ret:
     } /* while de = readdir */
     closedir(d);
     if (verbose)
-	printf("%s: %d articles posted.\n", current_server->name, n);
-    syslog(LOG_INFO, "%s: %d articles posted.", current_server->name, n);
+	printf("%s: %d article%s posted.\n", current_server->name, n, PLURAL(n));
+    syslog(LOG_INFO, "%s: %d article%s posted.", current_server->name, n, PLURAL(n));
     fchdir(savedir);
     close(savedir);
     return 1;
